<?php
/**
 * Some people get confused, and think factories/modules ARE stand-alone
 * plugins. If they try to activate this factory as if it was a plugin, they will
 * be shown a message explaining how to install aLinks.
 */
if (!defined('ALINKS_RUNNING')) {
	/**
	Plugin Name: Tags to Keyphrases Factory
	Description: aLinks factory component
	*/
	add_action('admin_notices', create_function(null, '
	?>
	<div id="alinks_notice" class="updated fade-ff0000">
		<p><strong>Error</strong><br />
		You activated an aLinks factory as a plugin. It is a component of the aLinks. It is not a WordPress plugin. You must have aLinks installed to
		use this.</p><p>You can download aLinks from <a href="http://alinks.headzoo.com/download">here</a>. Once you have aLinks installed
		and activated, you can install this factory following the directions in the <a href="http://alinks.headzoo.com/documentation">documentation</a>.</p?
	</div>
	<?php
	'));
	return;
}

/**
 * @see Alinks_Factory_Abstract
 */
require_once('Alinks/Factory/Abstract.php');

/**
 * Tags to Keyphrases Factory
 *
 *
 * @author Sean Hickey <sean@headzoo.com>
 * @version $Id: factory.php 396 2008-07-04 21:44:45Z sean $
 */
class Alinks_Factory_TagsToKeyphrases extends Alinks_Factory_Abstract
{
	/**
	 * The name of the factory
	 *
	 * @var string
	 */
	protected $_name = 'Tags to Keyphrases';
	
	/**
	 * The factory safe name
	 *
	 * @var string
	 */
	protected $_safe_name = 'tags_to_keyphrases';
	
	/**
	 * The URL for the factory
	 *
	 * @var string
	 */
	protected $_url = 'http://alinks.headzoo.com/factories/tags_to_keyphrases';
	
	/**
	 * A short description of the factory
	 *
	 * @var string
	 */
	protected $_description = 'Uses your post tags as keyphrases, which link to the tagged posts. Must be using WordPress 2.5 or greater.';
	
	/**
	 * The factory authors
	 *
	 * @var array
	 */
	protected $_authors = array('name' => 'Sean Hickey', 'url' => 'http://headzoo.com');
	
	/**
	 * The factory version
	 *
	 * @var float
	 */
	protected $_version = 1.0;
	
	/**
	 * The version of aLinks the factory is compatible with
	 *
	 * @var string
	 */
	protected $_alinks_version = '2.*';
	
	/**
	 * The version of WordPress this factory is compatible with
	 *
	 * @var string
	 */
	protected $_wp_version = '2.5*';
	
	/**
	 * Whether this factory has a settings form
	 *
	 * @var bool
	 */
	protected $_has_settings_form = false;
	
	/**
	 * Whether this factory has a keyphrases form
	 *
	 * @var bool
	 */
	protected $_has_keyphrases_form = false;

	/**
	 * Whether the factory has HTML to display on the Help page
	 *
	 * @var bool
	 */
	protected $_has_help = false;
	
	/**
	 * The keyphrases created by this factory
	 *
	 * @var Alinks_Keyphrase[]
	 */
	protected static $_keyphrases = null;
	
	/**
	 * Returns the keyphrases created by this factory
	 *
	 * @return Alinks_Keyphrase[]
	 */
	public function getKeyphrases()
	{
		if (null !== self::$_keyphrases) {
			return self::$_keyphrases;
		}
		$wpdb = Alinks_Registry::get('wpdb');
		
		self::$_keyphrases = array();
		$sql = "SELECT * FROM {$wpdb->posts}
		LEFT JOIN {$wpdb->term_relationships} ON {$wpdb->term_relationships}.object_id = {$wpdb->posts}.ID
		LEFT JOIN {$wpdb->terms} ON {$wpdb->terms}.term_id = {$wpdb->term_relationships}.term_taxonomy_id
		WHERE {$wpdb->posts}.post_status = 'publish' AND {$wpdb->posts}.post_type = 'post'";
		$results = $wpdb->get_results($sql);
		
		foreach($results as $result) {
			$keyphrase = new Alinks_Keyphrase($this->_safe_name);
			$keyphrase->setPhrase($result->name);
			$keyphrase->addOption('url', get_permalink($result->ID));
			$keyphrase->addOption('post_id', $result->ID);
			self::$_keyphrases[] = $keyphrase;
		}
		
		return self::$_keyphrases;
	}
	
	/**
	 * Replaces a keyphrase with a link
	 *
	 * @param Alinks_Keyphrase_Interface $keyphrase The keyphrase
	 * @param Alinks_LinkBuilder_Interface $builder The link builder
	 * @return Alinks_LinkBuilder_Interface
	 */
	public function parse(Alinks_Keyphrase_Interface $keyphrase, Alinks_LinkBuilder_Interface $builder)
	{
		global $post;
		if ($post && $post->ID != $keyphrase->getOptions('post_id')) {
			$builder->setUri($keyphrase->getOptions('url'));
		}
	}
}