<?php
/**
 * Interface for export classes
 *
 * Copyright (C) 2008  Sean Hickey
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @author Sean Hickey <sean@headzoo.com>
 * @version $Id: Interface.php 390 2008-07-03 05:40:51Z sean $
 * @package Alinks_ImportExport
 */
interface Alinks_ImportExport_Export_Interface
{
	/**
	 * Sets the export options
	 *
	 * @param array $options The export options
	 * @return Alinks_ImportExport_Export_Interface
	 */
	function setOptions(array $options);
	
	/**
	 * Adds a single export option
	 *
	 * @param string $key The option key
	 * @param mixed $value The option value
	 * @return Alinks_ImportExport_Export_Interface
	 */
	function addOption($key, $value);
	
	/**
	 * Returns the export options
	 *
	 * If $key is specified, then only the option value for that
	 * key will be returned. Otherwise the full array of options
	 * will be returned.
	 *
	 * @param string $key The option key
	 * @return mixed
	 * @throws Alinks_ImportExport_Export_Exception
	 */
	function getOptions($key = null);
	
	/**
	 * Returns the export data as a string
	 *
	 * @return string
	 */
	function export();
	
	/**
	 * Returns the MIME type for the exported document
	 *
	 * @return string
	 */
	function getMimeType();
	
	/**
	 * Returns the file extension for the exported document
	 *
	 * @return string
	 */
	function getFileExt();
}